EDuke32 Changelog Unofficial archive

Build 2044

25 September 2011 · 3 commits by 1 author · SVN

Builds by month 2 builds

  1. Jan

  2. Feb

  3. Mar

  4. Apr

  5. May

  6. Jun

  7. Jul

  8. Aug

  9. Sep

  10. Oct

  11. Nov

  12. Dec

Original log file · 20110925-2044.txt
------------------------------------------------------------------------
r2044 | helixhorned | 2011-09-25 08:11:47 -0700 (Sun, 25 Sep 2011) | 1 line

lunatic bits and pieces
------------------------------------------------------------------------
r2043 | helixhorned | 2011-09-25 08:11:28 -0700 (Sun, 25 Sep 2011) | 2 lines

When inserting a new sprite and determining its picnum by frequency count
of the picnums of all sprites, omit the newly inserted sprite itself!
------------------------------------------------------------------------
r2042 | helixhorned | 2011-09-25 08:11:11 -0700 (Sun, 25 Sep 2011) | 4 lines

VPX: in 3 planes -> packed format conversion code, group together the
three individual loops and compile the enclosing function at -O3 (-O1 for
debugging builds). Now, the time for this conversion ranges from 7 to 18
ms per frame across various tested machines, a clear improvement.
------------------------------------------------------------------------
r2041 | helixhorned | 2011-09-22 09:53:10 -0700 (Thu, 22 Sep 2011) | 2 lines

synthesis: package ebacktrace1.dll, remove backtrace.dll and libi*.dll
Makefile: remove ebacktrace1.dll on 'veryclean' target
------------------------------------------------------------------------
Engine

When inserting a new sprite and determining its picnum by frequency count

Philipp Kutin (Helixhorned) 25 Sep 2011, 08:11 UTC−7 r2043

of the picnums of all sprites, omit the newly inserted sprite itself!

VPX

in 3 planes -> packed format conversion code, group together the

Philipp Kutin (Helixhorned) 25 Sep 2011, 08:11 UTC−7 r2042

three individual loops and compile the enclosing function at -O3 (-O1 for debugging builds). Now, the time for this conversion ranges from 7 to 18 ms per frame across various tested machines, a clear improvement.